#
# spec file for package eclipse-swt
#
# Copyright (c) 2014 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           eclipse-swt
Summary:        SWT Library for GTK2
License:        EPL-1.0
Group:          Development/Libraries/Other
Version:        4.333
Release:        10.2
%define	        version_suffix 4.3.3.3
%define	        so_suffix 4333
Url:            http://www.eclipse.org/swt/
Source0:        libswt-%{version}.tar.bz2
Source1:        org.eclipse.swt-4.3.1.tar.bz2
Source2:        build.xml
Patch0:         libswt-optflags.patch
Patch1:         libswt-includes.patch
Patch2:         libswt-build.patch
Patch3:         libswt-plugindir.patch
Patch4:         ppc64le.patch
Patch5:         ppc64le_path_for_jre_1_7_0.patch
Provides:       libswt3-gtk2 = %{version}
%if 0%{?suse_version} <= 1210
Requires:       mozilla-xulrunner192
%endif
Requires:       java >= 1.6
BuildRequires:  ant
BuildRequires:  gcc
BuildRequires:  gcc-c++
BuildRequires:  java-devel >= 1.6
BuildRequires:  jpackage-utils
BuildRequires:  libgcj-devel
BuildRequires:  libwebkit-devel
BuildRequires:  make
BuildRequires:  pkg-config
BuildRequires:  unzip
BuildRequires:  zip
%if 0%{?suse_version} <= 1210
BuildRequires:  mozilla-xulrunner192-devel
BuildRequires:  libxslt
%else
BuildRequires:  libXt-devel
BuildRequires:  libXtst-devel
%endif
BuildRequires:  Mesa-devel
BuildRequires:  cairo
BuildRequires:  glib2-devel
BuildRequires:  gnome-vfs2-devel
BuildRequires:  gtk2-devel
BuildRequires:  libgnome-devel
BuildRequires:  libgnomeui-devel
BuildRequires:  mozilla-nspr-devel
BuildRequires:  pkgconfig(glu)

%description
SWT is the software component that delivers native widget functionality
for the Eclipse platform in an operating system independent manner.  It
is analogous to AWT/Swing in Java with a difference - SWT uses a rich
set of native widgets.

%prep
%setup -q -n libswt-%{version}
%patch0
%patch1
%patch2
pushd org/eclipse
tar -xjf %{S:1}
%patch3
popd
%patch4
# for ppc64le Leap 42 the Java 1.7 still have ppc64le path
%if 0%{?suse_version} <= 1315
%ifarch ppc64le
%patch5 -p1
%endif
%endif
pushd org/eclipse/swt
cp %{S:2} .
# remove all third party jars
find . -iname '*.jar' | xargs rm -rf
popd

%build
export LIBDIR=%{_libdir}
export NO_STRIP=TRUE
%if 0%{?suse_version} <= 1140
export GCJ_VERSION=4.5
%else
%if 0%{?suse_version} <= 1210
export GCJ_VERSION=4.6
%else
export GCJ_VERSION=4.7
%endif
%endif
%ifarch x86_64
export ARCH=x86_64
%else
export ARCH=i586
%endif
./build.sh

pushd org/eclipse/swt
%ant \
%ifarch x86_64
    -Dswt.arch=x86_64 \
%else
    -Dswt.arch=x86 \
%endif
    -Dversion.suffix=%{version_suffix} \
    -Djar.filename=swt-%{version}.jar \
    build.jars
rm build.xml
popd
zip -u org/eclipse/swt/swt-%{version}.jar *.so
%install
install -d -m755 %{buildroot}%{_libdir}/eclipse
install -m644 *.so %{buildroot}%{_libdir}/eclipse
install -D -m644 org/eclipse/swt/swt-%{version}.jar %{buildroot}%{_libdir}/java/swt-gtk-%{version}.jar
pushd %{buildroot}%{_libdir}/eclipse
%if 0%{?suse_version} < 1210
for i in atk-gtk awt-gtk cairo-gtk glx-gtk gnome-gtk gtk mozilla-gtk pi-gtk webkit-gtk; do
  ln -sf libswt-"$i"-%{so_suffix}.so libswt-"$i".so;
  ln -sf libswt-"$i"-%{so_suffix}.so swt-"$i".so;
done
%else
# Drop mozilla-gtk in openSUSE 12.2 because of not existing mozilla-xulrunner192-devel
for i in atk-gtk awt-gtk cairo-gtk glx-gtk gnome-gtk gtk pi-gtk webkit-gtk; do
  ln -sf libswt-"$i"-%{so_suffix}.so libswt-"$i".so;
  ln -sf libswt-"$i"-%{so_suffix}.so swt-"$i".so;
done
%endif
popd
pushd %{buildroot}%{_libdir}/java
ln -sf swt-gtk-%{version}.jar swt.jar
ln -sf swt-gtk-%{version}.jar swt-gtk.jar
popd

%files
%defattr(-,root,root)
%{_libdir}/eclipse/libswt-atk-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-atk-gtk.so
%{_libdir}/eclipse/swt-atk-gtk.so
%{_libdir}/eclipse/libswt-awt-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-awt-gtk.so
%{_libdir}/eclipse/swt-awt-gtk.so
%{_libdir}/eclipse/libswt-cairo-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-cairo-gtk.so
%{_libdir}/eclipse/swt-cairo-gtk.so
%{_libdir}/eclipse/libswt-glx-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-glx-gtk.so
%{_libdir}/eclipse/swt-glx-gtk.so
%{_libdir}/eclipse/libswt-gnome-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-gnome-gtk.so
%{_libdir}/eclipse/swt-gnome-gtk.so
%{_libdir}/eclipse/libswt-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-gtk.so
%{_libdir}/eclipse/swt-gtk.so
%if 0%{?suse_version} < 1210
%{_libdir}/eclipse/libswt-mozilla-gtk.so
%{_libdir}/eclipse/swt-mozilla-gtk.so
%endif
%{_libdir}/eclipse/libswt-pi-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-pi-gtk.so
%{_libdir}/eclipse/swt-pi-gtk.so
%{_libdir}/eclipse/libswt-webkit-gtk-%{so_suffix}.so
%{_libdir}/eclipse/libswt-webkit-gtk.so
%{_libdir}/eclipse/swt-webkit-gtk.so
%{_libdir}/java/swt.jar
%{_libdir}/java/swt-gtk.jar
%{_libdir}/java/swt-gtk-%{version}.jar
%doc about_files/*
%dir %{_libdir}/eclipse
%dir %{_libdir}/java

%changelog
* Fri Aug 28 2015 normand@linux.vnet.ibm.com
-  new patch for ppc64le for suse_version <= 1315
  ppc64le_path_for_jre_1_7_0.patch
* Wed Aug 12 2015 dvaleev@suse.com
- Fix SWT_ARCH on ppc64le (refresh ppc64le.patch)
* Tue Jul  1 2014 tchvatal@suse.com
- Revert back to 4.333 as it broke build of only dependant package
- Removed patches:
  * build.patch
  * jni64.patch
- Added patches:
  * libswt-includes.patch
  * libswt-build.patch
  * libswt-optflags.patch
  * libswt-plugindir.patch
  * ppc64le.patch
* Mon May 19 2014 schwab@suse.de
- Fix bogus arch setting
- jni64.patch: Fix JNI64 setting
- build.patch: Fix AWT_ARCH setting
* Fri May 16 2014 mailaender@opensuse.org
- update to version 4.335 (Eclipse Kepler Service Release 2)
- https://en.opensuse.org/SourceUrls
- only use the upstream provided parametrized ant scripts
- dropped all patches hacking a custom build system
* Tue Jan 14 2014 embar@super.lt
- Fix build for openSUSE Tumbleweed and 11.4
* Tue Jan 14 2014 joerg.lorenzen@ki.tng.de
- update to version 4.333
- remove libswt-version.patch
- add libswt-plugindir.patch
* Thu Jan  2 2014 dvaleev@suse.com
- enable ppc64le build
- add ppc64le.patch
* Wed Oct 17 2012 embar@super.lt
- Fix build for openSUSE Factory
* Fri Sep 21 2012 idonmez@suse.com
- Add explicit glu dependency
* Fri Jun 29 2012 coolo@suse.com
- use use one libgcj to rule them all
* Wed Jun 13 2012 embar@super.lt
- Remove mozilla-xulrunner192 dependency (fix bnc#766485)
* Fri Nov 25 2011 embar@super.lt
- Use libgcj45 for openSUSE 11.4 and older versions
- Fix bnc#732684
* Mon Oct 24 2011 coolo@suse.com
- use gcc46
* Wed Sep 21 2011 cfarrell@suse.com
- license update: Eclipse-1.0
  Use SPDX format (http://www.spdx.org/licenses)
* Fri Jul  1 2011 joerg.lorenzen@ki.tng.de
- update to version 3.735
* Wed May 18 2011 joerg.lorenzen@ki.tng.de
- update to version 3.730
* Thu Mar 17 2011 joerg.lorenzen@ki.tng.de
- update to version 3.724
* Tue Feb  8 2011 joerg.lorenzen@ki.tng.de
- update to version 3.712
* Sat Oct  9 2010 joerg.lorenzen@ki.tng.de
- update to version 3.655
* Wed Sep 15 2010 joerg.lorenzen@ki.tng.de
- Initial package, version 3.650
